#!/usr/bin/python

### GAD PIPELINE ###
## create_counts_matrix.py
## Description : This script allows user to create counts matrix for RnaSeq data
## Usage : python create_counts_matrix.py -i <fileslist/file> -o <output/matrix/file> -e <log/file>
## Output : tabulated output file with read count for each gene
## Requirements : python 2.7

## Author : Emilie.Tisserant@u-bourgogne.fr
## Creation Date : 20170331
## last revision date : 20170331
## Known bugs : None


import os
import sys
import getopt
import logging


try:
    opts, args = getopt.getopt(sys.argv[1:], 'i:o:e:')
    for opt, arg in opts:
        if opt in ("-i"):
            inputfile = arg
        elif opt in ("-o"):
            sys.stdout = open(arg, 'w')
        elif opt in ("-e"):
            logfile = arg
except getopt.GetoptError:
    print """
Usage : python create_counts_matrix.py -i <fileslist/file> -o <output/matrix/file> -e <log/file>
"""
    sys.exit(1)

# Logging
logging.basicConfig(filename =  '%s' % (logfile), filemode = 'a', level = logging.INFO, format = '%(asctime)s %(levelname)s - %(message)s')
logging.info('start')

# Manage options
if not vars().has_key('inputfile'):
    logging.exception('No input file given')
    sys.exit(1)

# Check input files
try:
	f = open(inputfile, 'r')
	f.close()
except IOError:
    logging.exception('Input file does not exist')
    sys.exit(1)

# Create list for files
files_list = []
liststream = open(inputfile, 'r')
for line in liststream:
    line = line.strip()
    tabs = line.split("\t")
    files_list.append(tabs[0])
liststream.close()

# Read count files
samplelist = []
genelist = []
matrixdict = {}
i = 0
for f in files_list:
    samplelist.append(f.split("/")[-1].split(".")[0])
    stream = open(f, 'r')
    for line in stream:
        line = line.strip()
        tabs = line.split("\t")
        if not line.startswith('N_'):
            if i == 0:
                genelist.append(tabs[0])
            matrixdict.setdefault(tabs[0], []).append(tabs[1])
    stream.close()
    i += 1

# Print matrix
print "Genes"+"\t"+"\t".join(samplelist)
for gene in genelist:
    print gene+"\t"+"\t".join(matrixdict[gene])

logging.info('end')
