#!/bin/ksh

### GAD PIPELINE ###
## wrapper_list_counts.sh
## Description : This script create a design file based on the batch analysis
## Usage : qsub -pe smp 1 -v INPUTDIR=</path/to/the/input/dir>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] wrapper_list_counts.sh
## Output : tabulated output file with path to files containing counts
## Requirements : GAD pipeline directory structure

## Author : yannis.duffourd@u-bourgogne.fr
## Creation Date : 20200929
## last revision date : 20200929
## Known bugs : None

#$ -q batch
#$ -pe smp 1
#$ -V


# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=wrapper_list_counts.$(date +"%F_%H-%M-%S").log
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if config file exist
if [ ! -f $CONFIGFILE ]
then
    echo "Config file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch wrapper_list_counts.failed
    exit 1
fi

# Check if input dir exist
if [ -z ${INPUTDIR} ]
then
    echo "Input Directory does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch wrapper_list_counts.failed
    exit 1
fi

# generate the list of count files
echo "ls -1 $INPUTDIR/*/*.ReadsPerGene.out.tab > $INPUTDIR/all.counts.files.tsv"
ls -1 $INPUTDIR/*/*.ReadsPerGene.out.tab > $INPUTDIR/all.counts.files.tsv

createlist_exitcode=$?
echo "Create list exit code : $createlist_exitcode"

if [ $createlist_exitcode != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch wrapper_list_counts.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"
