#!/bin/bash


### GAD PIPELINE ###
## process_fastqc.sh
## Version : 2.4.0
## Description : This script allows user to launch FastQC quality control on several fastq.gz files 
## Usage : qsub -pe smp 1 -v INPUTFILE=</path/to/the/sample/file>,[OUTDIR=/path/to/the/output/directory],[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] process_fastqc.sh
## Output : FastQC output files
## Requirements : JRE, FastQC v0.11.2

## Author : Emilie.Tisserant@u-bourgogne.fr
## Creation Date : 08/06/2015
## last revision date : 18/08/2015
## Known bugs : None

#$ -q batch
#$ -V

# Log file path option
if [ -z ${LOGFILE} ]
then
    LOGFILE=process_fastqc.$(date +"%F_%H-%M-%S").log
fi

# Output directory path option
if [ -z ${OUTDIR} ]
then
    OUTDIR=fastqc
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi

JAVA=$(grep "javacmd" $CONFIGFILE | awk '{print $2" "$3}')
FASTQCBIN=$(grep "fastqccmd" $CONFIGFILE | awk '{print $2}')
LIMITS_FILE=$(grep "fastqc_config" $CONFIGFILE | awk '{print $2}')
TEMPORARY_DIR=$(grep "temporary_dir" $CONFIGFILE | awk '{print $2}')

# Logging
#exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START" >> $LOGFILE

# Check if config file exist
if [ ! -f $CONFIGFILE ]
then
    echo "Config file does not exist" >> $LOGFILE
    echo "$(date +"%F_%H-%M-%S"): END" >> $LOGFILE
    touch process_fastqc.failed
    exit 1
fi

# Check if input file exist
if [ ! -f $INPUTFILE ]
then
    echo "Input file does not exist" >> $LOGFILE
    echo "$(date +"%F_%H-%M-%S"): END" >> $LOGFILE
    touch process_fastqc.failed
    exit 1
fi

# Check if output directory exists
if [ ! -d $OUTDIR ]
then
    mkdir $OUTDIR
fi

# Process fastqc for each fastq.gz file and check exit code
echo "fastqc command: $FASTQCBIN $INPUTFILE --extract -d $TEMPORARY_DIR -o $OUTDIR -j $JAVA -t $NSLOTS --limits $LIMITS_FILE" >> $LOGFILE
$FASTQCBIN $INPUTFILE --extract -d $TEMPORARY_DIR -o $OUTDIR -j $JAVA -t $NSLOTS --limits $LIMITS_FILE
fastqc_exitcode=$?
echo "FastQC exit code : $fastqc_exitcode" >> $LOGFILE
if [ $fastqc_exitcode != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END" >> $LOGFILE
    touch process_fastqc.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END" >> $LOGFILE
