#!/bin/bash

### GAD PIPELINE ###
## wrapper_annotate_SJ_with_OMIM.sh
## Description : annotate a SJ file with OMIM data
## Usage : qsub -v INPUTFILE=</path/to/the/SJ/file>,OUTPUTFILE=</path/to/the/annotated/SJ/file>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] wrapper_annotate_SJ_with_OMIM.sh
## Output : a tabulated SJ file including OMIM annotation
## Requirements : python 2.7

## Author : emilie.tisserant@u-bourgogne.fr ; yannis.duffourd@u-bourgogne.fr
## Creation Date : 20180417
## last revision date : 20201016
## Known bugs : None

#$ -V
#$ -q batch

# logfile
if [ -z ${LOGFILE} ]
then
    LOGFILE=annotate_SJ_with_OMIM.$(date +"%F_%H-%M-%S").log
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if input file exist
if [ ! -f $INPUTFILE ]
then
    echo "Input file does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_SJ_with_OMIM.failed
    exit 1
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
   CONFIGFILE=analysis_config.tsv
fi

PYTHONBIN=$(grep "pythonbin" $CONFIGFILE | awk '{print $2}')
PIPELINEBASE=$(grep "pipelinebase" $CONFIGFILE | cut -f2)
OMIM=$(grep "omim_list" $CONFIGFILE | cut -f2)

echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/annotate_SJ_with_OMIM.py -d $OMIM -i $INPUTFILE -o $OUTPUTFILE"
$PYTHONBIN $PIPELINEBASE/common/splice/annotate_SJ_with_OMIM.py -d $OMIM -i $INPUTFILE -o $OUTPUTFILE
exit_code=$?
echo "wrapper_annotate_SJ_with_OMIM.sh exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_SJ_with_OMIM.failed
    exit 1
fi


echo "$(date +"%F_%H-%M-%S"): END"
