#!/bin/bash

### GAD PIPELINE ###
## wrapper_annotate_report_with_rnaseq.sh
## Description : annotate a report file (from wgs analysis) with rnaseq analysis results
## Usage : qsub -v SAMPLE=<SAMPLE name>,TYPE=[NSSSI|GENIC],[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] wrapper_annotate_report_with_rnaseq.sh
## Output : report file including 5 new fields of rnaseq data
##					The pipeline haven't the knowledge of the dijen corresp or NSSSI/GENIC name, at the time when jobs are scheduled.
##					So this is computed in this wrapper.
## Requirements : python 2.7, a variant report from wgs experiment

## Author : yannis.duffourd@u-bourgogne.fr
## Creation Date : 20201020
## last revision date : 20201213
## Known bugs : None

#$ -V
#$ -q batch

# logfile
if [ -z ${LOGFILE} ]
then
    LOGFILE=annotate_report_with_rnaseq.$(date +"%F_%H-%M-%S").log
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Config file path option
if [ -z ${CONFIGFILE} ]
then
   CONFIGFILE=analysis_config.tsv
fi

PYTHONBIN=$(grep "pythonbin" $CONFIGFILE | awk '{print $2}')
PIPELINEBASE=$(grep "pipelinebase" $CONFIGFILE | cut -f2)

# need to check first if there is a report file for the SAMPLE.
INPUTFILE=""
if [ -e "$SAMPLE/$SAMPLE.dijen.corresp.tsv" ]
then
  DIJEN=$(grep "dijen" $SAMPLE/$SAMPLE.dijen.corresp.tsv)
	if [ "$TYPE" == "NSSSI" ]
	then
		INPUTFILE=$SAMPLE/$DIJEN.nsssi.$SAMPLE.rare.report.tsv
		if [ ! -e "$INPUTFILE" ]
		then
			echo "No nsssi file for this dijarn"
			echo "$(date +"%F_%H-%M-%S"): END"
			exit 1
		fi
	else
		INPUTFILE=$SAMPLE/$DIJEN.genic.$SAMPLE.rare.report.tsv
		if [ ! -e "$INPUTFILE" ]
		then
			echo "No genic file for this dijarn"
			echo "$(date +"%F_%H-%M-%S"): END"
			exit 1
		fi
  fi
else
	echo "No dijen corresp for this dijarn"
	echo "$(date +"%F_%H-%M-%S"): END"
	exit 0
fi

# deal with nsssi / genic part of the output file names
SUFFIX=""
if [ "$TYPE" == "NSSSI" ]
then
	SUFFIX="nsssi"
fi
if [ "$TYPE" == "GENIC" ]
then
	SUFFIX="genic"
fi

echo "test"

echo "Type is $TYPE ; SUFFIX is : $SUFFIX"

echo "retest"

# deseq
TMPOUTFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.report.tsv
echo "Command : $PYTHONBIN $PIPELINEBASE/common/DE/annotate_report_with_aberrant_expr_deseq.py -i $INPUTFILE -o $TMPOUTFILE -e $SAMPLE/$SAMPLE.DE_analysis.DE.tsv"
$PYTHONBIN $PIPELINEBASE/common/DE/annotate_report_with_aberrant_expr_deseq.py -i $INPUTFILE -o $TMPOUTFILE -e $SAMPLE/$SAMPLE.DE_analysis.DE.tsv
exit_code=$?
echo "wrapper_annotate_report_with_rnaseq.sh exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_report_with_rnaseq.failed
    exit 1
fi

# outrider
TMPINFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.report.tsv
TMPOUTFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.outrider.report.tsv
echo "Command : $PYTHONBIN $PIPELINEBASE/common/DE/annotate_report_with_aberrant_expr_deseq.py -i $TMPINFILE -o $TMPOUTFILE -e $SAMPLE/outrider.sign.tsv -s $SAMPLE"
$PYTHONBIN $PIPELINEBASE/common/DE/annotate_report_with_aberrant_expr_outrider.py -i $TMPINFILE -o $TMPOUTFILE -e $SAMPLE/outrider.sign.tsv -s $SAMPLE
exit_code=$?
echo "wrapper_annotate_report_with_rnaseq.sh exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_report_with_rnaseq.failed
    exit 1
fi

# leafcutter
TMPINFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.outrider.report.tsv
TMPOUTFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.outrider.leafcutter.report.tsv
echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/annotate_report_with_aberrant_splice_Leafcutter.py -i $TMPINFILE -o $TMPOUTFILE -e $SAMPLE/$SAMPLE.leafcutter.report.tsv"
$PYTHONBIN $PIPELINEBASE/common/splice/annotate_report_with_aberrant_splice_Leafcutter.py -i $TMPINFILE -o $TMPOUTFILE -e $SAMPLE/$SAMPLE.leafcutter.report.tsv
exit_code=$?
echo "wrapper_annotate_report_with_rnaseq.sh exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_report_with_rnaseq.failed
    exit 1
fi

# rMATs
TMPINFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.outrider.leafcutter.report.tsv
TMPOUTFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.outrider.leafcutter.rmats.report.tsv
echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/annotate_report_with_aberrant_splice_rMATs.py -i $TMPINFILE -o $TMPOUTFILE -e $SAMPLE/rMATS.filtered.tsv"
$PYTHONBIN $PIPELINEBASE/common/splice/annotate_report_with_aberrant_splice_rMATs.py -i $TMPINFILE -o $TMPOUTFILE -e $SAMPLE/rMATS.filtered.tsv
exit_code=$?
echo "wrapper_annotate_report_with_rnaseq.sh exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_report_with_rnaseq.failed
    exit 1
fi

# SJ
TMPINFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.outrider.leafcutter.rmats.report.tsv
TMPOUTFILE=$SAMPLE/$DIJEN.$SAMPLE.$SUFFIX.deseq.outrider.leafcutter.rmats.SJ.report.tsv
echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/annotate_report_with_aberrant_splice_SJ.py -i $TMPINFILE -o $TMPOUTFILE  -e $SAMPLE/$SAMPLE.SJ.annot.tsv"
$PYTHONBIN $PIPELINEBASE/common/splice/annotate_report_with_aberrant_splice_SJ.py -i $TMPINFILE -o $TMPOUTFILE -e $SAMPLE/$SAMPLE.SJ.annot.tsv
exit_code=$?
echo "wrapper_annotate_report_with_rnaseq.sh exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch annotate_report_with_rnaseq.failed
    exit 1
fi

# Filter
# TODO















echo "$(date +"%F_%H-%M-%S"): END"
