#!/bin/bash

### GAD PIPELINE ###
## wrapper_postprocessing_rMATs.sh
## Description : clustering of leafcutter junctions
## Usage : qsub -v INPUTDIR=<sample directory>,OUTPUTFILE=<output bed filename>,ZSCORE=<zscore threshold>,DELTAPSY=<delta psy threshold>,[LOGFILE=/path/to/the/log/file],[CONFIGFILE=/path/to/the/config/file] wrapper_postprocessing_rMATs.sh
## Output : 1 bed file for the sample
## Requirements : python 2.x, numpy

## Author : yannis.duffourd@u-bourgogne.fr
## Creation Date : 20201007
## last revision date : 20201007
## Known bugs : None

#$ -V
#$ -q batch
#$ -pe smp 1

# logfile
if [ -z ${LOGFILE} ]
then
    LOGFILE=postprocessing_rMATs.$(date +"%F_%H-%M-%S").log
fi

# Logging
exec 1>> $LOGFILE 2>&1
echo "$(date +"%F_%H-%M-%S"): START"

# Check if input directory exist
if [ -z $INPUTDIR ]
then
    echo "Input directory does not exist"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch postprocessing_rMATs.failed
    exit 1
fi

# Check if output file is specified
if [ -z $OUTPUTFILE ]
then
    echo "Output file is not specified"
    echo "$(date +"%F_%H-%M-%S"): END"
    touch postprocessing_rMATs.failed
    exit 1
fi

# Config file path option
if [ -z ${CONFIGFILE} ]
then
    CONFIGFILE=analysis_config.tsv
fi


PYTHONBIN=$(grep "pythonbin" $CONFIGFILE | awk '{print $2}')
PIPELINEBASE=$(grep "pipelinebase" $CONFIGFILE | cut -f2)

FORMATTMPFILE="$INPUTDIR/rMATS.format.tsv"
FILTERTMPFILE="$INPUTDIR/rMATS.filtered.tsv"

# format output
echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/format_rMATS.py -i $INPUTDIR -o $FORMATTMPFILE"
$PYTHONBIN $PIPELINEBASE/common/splice/format_rMATS.py -i $INPUTDIR -o $FORMATTMPFILE
exit_code=$?
echo "wrapper_postprocessing_rMATs.sh format exit code : $exit_code"
if [ $exit_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch postprocessing_rMATs.failed
    exit 1
fi



# filter output
echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/filter_rMATS.py -i $FORMATTMPFILE -o $FILTERTMPFILE -d $DELTAPSY -z $ZSCORE"
$PYTHONBIN $PIPELINEBASE/common/splice/filter_rMATS.py -i $FORMATTMPFILE -o $FILTERTMPFILE -d $DELTAPSY -z $ZSCORE
postprocessing_rMATs_code=$?
echo "wrapper_postprocessing_rMATs.sh filter exit code : $postprocessing_rMATs_code"
if [ $postprocessing_rMATs_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch postprocessing_rMATs.failed
    exit 1
fi

# convert to bed
echo "Command : $PYTHONBIN $PIPELINEBASE/common/splice/convert_rMATS_to_bed.py -i $FILTERTMPFILE -o $OUTPUTFILE"
$PYTHONBIN $PIPELINEBASE/common/splice/convert_rMATS_to_bed.py -i $FILTERTMPFILE -o $OUTPUTFILE
postprocessing_rMATs_code=$?
echo "wrapper_postprocessing_rMATs.sh convert_to_bed exit code : $postprocessing_rMATs_code"
if [ $postprocessing_rMATs_code != 0 ]
then
    echo "$(date +"%F_%H-%M-%S"): END"
    touch postprocessing_rMATs.failed
    exit 1
fi

echo "$(date +"%F_%H-%M-%S"): END"
